@@ -18,11 +18,13 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains the ChosenInlineResultHandler class."""
 
+from typing import Optional, TypeVar, Union
+
 from telegram import Update
+from telegram.utils.types import HandlerArg
+
 from .handler import Handler
 
-from telegram.utils.types import HandlerArg
-from typing import Optional, Union, TypeVar
 RT = TypeVar('RT')
 
 
