@@ -16,9 +16,11 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
+# pylint: disable=R0201, E0401
 """This module contains the class Defaults, which allows to pass default values to Updater."""
+from typing import Any, NoReturn, Optional, Union
+
 import pytz
-from typing import Union, Optional, Any, NoReturn
 
 from telegram.utils.helpers import DEFAULT_NONE, DefaultValue
 
@@ -33,6 +35,8 @@ class Defaults:
             receive a notification with no sound.
         disable_web_page_preview (:obj:`bool`): Optional. Disables link previews for links in this
             message.
+        allow_sending_without_reply (:obj:`bool`): Optional. Pass :obj:`True`, if the message
+            should be sent even if the specified replied-to message is not found.
         timeout (:obj:`int` | :obj:`float`): Optional. If this value is specified, use it as the
             read timeout from the server (instead of the one specified during creation of the
             connection pool).
@@ -41,6 +45,9 @@ class Defaults:
             be ignored. Default: :obj:`True` in group chats and :obj:`False` in private chats.
         tzinfo (:obj:`tzinfo`): A timezone to be used for all date(time) objects appearing
             throughout PTB.
+        run_async (:obj:`bool`): Optional. Default setting for the ``run_async`` parameter of
+            handlers and error handlers registered through :meth:`Dispatcher.add_handler` and
+            :meth:`Dispatcher.add_error_handler`.
 
     Parameters:
         parse_mode (:obj:`str`, optional): Send Markdown or HTML, if you want Telegram apps to show
@@ -49,6 +56,8 @@ class Defaults:
             receive a notification with no sound.
         disable_web_page_preview (:obj:`bool`, optional): Disables link previews for links in this
             message.
+        allow_sending_without_reply (:obj:`bool`, optional): Pass :obj:`True`, if the message
+            should be sent even if the specified replied-to message is not found.
         timeout (:obj:`int` | :obj:`float`, optional): If this value is specified, use it as the
             read timeout from the server (instead of the one specified during creation of the
             connection pool).
@@ -59,22 +68,32 @@ class Defaults:
             appearing throughout PTB, i.e. if a timezone naive date(time) object is passed
             somewhere, it will be assumed to be in ``tzinfo``. Must be a timezone provided by the
             ``pytz`` module. Defaults to UTC.
+        run_async (:obj:`bool`, optional): Default setting for the ``run_async`` parameter of
+            handlers and error handlers registered through :meth:`Dispatcher.add_handler` and
+            :meth:`Dispatcher.add_error_handler`. Defaults to :obj:`False`.
     """
-    def __init__(self,
-                 parse_mode: str = None,
-                 disable_notification: bool = None,
-                 disable_web_page_preview: bool = None,
-                 # Timeout needs special treatment, since the bot methods have two different
-                 # default values for timeout (None and 20s)
-                 timeout: Union[float, DefaultValue] = DEFAULT_NONE,
-                 quote: bool = None,
-                 tzinfo: pytz.BaseTzInfo = pytz.utc):
+
+    def __init__(
+        self,
+        parse_mode: str = None,
+        disable_notification: bool = None,
+        disable_web_page_preview: bool = None,
+        # Timeout needs special treatment, since the bot methods have two different
+        # default values for timeout (None and 20s)
+        timeout: Union[float, DefaultValue] = DEFAULT_NONE,
+        quote: bool = None,
+        tzinfo: pytz.BaseTzInfo = pytz.utc,
+        run_async: bool = False,
+        allow_sending_without_reply: bool = None,
+    ):
         self._parse_mode = parse_mode
         self._disable_notification = disable_notification
         self._disable_web_page_preview = disable_web_page_preview
+        self._allow_sending_without_reply = allow_sending_without_reply
         self._timeout = timeout
         self._quote = quote
         self._tzinfo = tzinfo
+        self._run_async = run_async
 
     @property
     def parse_mode(self) -> Optional[str]:
@@ -82,8 +101,10 @@ class Defaults:
 
     @parse_mode.setter
     def parse_mode(self, value: Any) -> NoReturn:
-        raise AttributeError("You can not assign a new value to defaults after because it would "
-                             "not have any effect.")
+        raise AttributeError(
+            "You can not assign a new value to defaults after because it would "
+            "not have any effect."
+        )
 
     @property
     def disable_notification(self) -> Optional[bool]:
@@ -91,8 +112,10 @@ class Defaults:
 
     @disable_notification.setter
     def disable_notification(self, value: Any) -> NoReturn:
-        raise AttributeError("You can not assign a new value to defaults after because it would "
-                             "not have any effect.")
+        raise AttributeError(
+            "You can not assign a new value to defaults after because it would "
+            "not have any effect."
+        )
 
     @property
     def disable_web_page_preview(self) -> Optional[bool]:
@@ -100,8 +123,21 @@ class Defaults:
 
     @disable_web_page_preview.setter
     def disable_web_page_preview(self, value: Any) -> NoReturn:
-        raise AttributeError("You can not assign a new value to defaults after because it would "
-                             "not have any effect.")
+        raise AttributeError(
+            "You can not assign a new value to defaults after because it would "
+            "not have any effect."
+        )
+
+    @property
+    def allow_sending_without_reply(self) -> Optional[bool]:
+        return self._allow_sending_without_reply
+
+    @allow_sending_without_reply.setter
+    def allow_sending_without_reply(self, value: Any) -> NoReturn:
+        raise AttributeError(
+            "You can not assign a new value to defaults after because it would "
+            "not have any effect."
+        )
 
     @property
     def timeout(self) -> Union[float, DefaultValue]:
@@ -109,8 +145,10 @@ class Defaults:
 
     @timeout.setter
     def timeout(self, value: Any) -> NoReturn:
-        raise AttributeError("You can not assign a new value to defaults after because it would "
-                             "not have any effect.")
+        raise AttributeError(
+            "You can not assign a new value to defaults after because it would "
+            "not have any effect."
+        )
 
     @property
     def quote(self) -> Optional[bool]:
@@ -118,8 +156,10 @@ class Defaults:
 
     @quote.setter
     def quote(self, value: Any) -> NoReturn:
-        raise AttributeError("You can not assign a new value to defaults after because it would "
-                             "not have any effect.")
+        raise AttributeError(
+            "You can not assign a new value to defaults after because it would "
+            "not have any effect."
+        )
 
     @property
     def tzinfo(self) -> pytz.BaseTzInfo:
@@ -127,16 +167,35 @@ class Defaults:
 
     @tzinfo.setter
     def tzinfo(self, value: Any) -> NoReturn:
-        raise AttributeError("You can not assign a new value to defaults after because it would "
-                             "not have any effect.")
+        raise AttributeError(
+            "You can not assign a new value to defaults after because it would "
+            "not have any effect."
+        )
+
+    @property
+    def run_async(self) -> Optional[bool]:
+        return self._run_async
+
+    @run_async.setter
+    def run_async(self, value: Any) -> NoReturn:
+        raise AttributeError(
+            "You can not assign a new value to defaults after because it would "
+            "not have any effect."
+        )
 
     def __hash__(self) -> int:
-        return hash((self._parse_mode,
-                     self._disable_notification,
-                     self._disable_web_page_preview,
-                     self._timeout,
-                     self._quote,
-                     self._tzinfo))
+        return hash(
+            (
+                self._parse_mode,
+                self._disable_notification,
+                self._disable_web_page_preview,
+                self._allow_sending_without_reply,
+                self._timeout,
+                self._quote,
+                self._tzinfo,
+                self._run_async,
+            )
+        )
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Defaults):
