@@ -18,9 +18,11 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains objects that represents stickers."""
 
-from telegram import PhotoSize, TelegramObject
+from typing import TYPE_CHECKING, Any, List, Optional, ClassVar
+
+from telegram import PhotoSize, TelegramObject, constants
 from telegram.utils.types import JSONDict
-from typing import Any, Optional, List, TYPE_CHECKING
+
 if TYPE_CHECKING:
     from telegram import Bot, File
 
@@ -71,19 +73,21 @@ class Sticker(TelegramObject):
 
     """
 
-    def __init__(self,
-                 file_id: str,
-                 file_unique_id: str,
-                 width: int,
-                 height: int,
-                 is_animated: bool,
-                 thumb: PhotoSize = None,
-                 emoji: str = None,
-                 file_size: int = None,
-                 set_name: str = None,
-                 mask_position: 'MaskPosition' = None,
-                 bot: 'Bot' = None,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        file_id: str,
+        file_unique_id: str,
+        width: int,
+        height: int,
+        is_animated: bool,
+        thumb: PhotoSize = None,
+        emoji: str = None,
+        file_size: int = None,
+        set_name: str = None,
+        mask_position: 'MaskPosition' = None,
+        bot: 'Bot' = None,
+        **_kwargs: Any,
+    ):
         # Required
         self.file_id = str(file_id)
         self.file_unique_id = str(file_unique_id)
@@ -158,15 +162,16 @@ class StickerSet(TelegramObject):
 
     """
 
-    def __init__(self,
-                 name: str,
-                 title: str,
-                 is_animated: bool,
-                 contains_masks: bool,
-                 stickers: List[Sticker],
-                 bot: 'Bot' = None,
-                 thumb: PhotoSize = None,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        name: str,
+        title: str,
+        is_animated: bool,
+        contains_masks: bool,
+        stickers: List[Sticker],
+        thumb: PhotoSize = None,
+        **_kwargs: Any,
+    ):
         self.name = name
         self.title = title
         self.is_animated = is_animated
@@ -227,16 +232,17 @@ class MaskPosition(TelegramObject):
         scale (:obj:`float`): Mask scaling coefficient. For example, 2.0 means double size.
 
     """
-    FOREHEAD: str = 'forehead'
-    """:obj:`str`: 'forehead'"""
-    EYES: str = 'eyes'
-    """:obj:`str`: 'eyes'"""
-    MOUTH: str = 'mouth'
-    """:obj:`str`: 'mouth'"""
-    CHIN: str = 'chin'
-    """:obj:`str`: 'chin'"""
 
-    def __init__(self, point: str, x_shift: float, y_shift: float, scale: float, **kwargs: Any):
+    FOREHEAD: ClassVar[str] = constants.STICKER_FOREHEAD
+    """:const:`telegram.constants.STICKER_FOREHEAD`"""
+    EYES: ClassVar[str] = constants.STICKER_EYES
+    """:const:`telegram.constants.STICKER_EYES`"""
+    MOUTH: ClassVar[str] = constants.STICKER_MOUTH
+    """:const:`telegram.constants.STICKER_MOUTH`"""
+    CHIN: ClassVar[str] = constants.STICKER_CHIN
+    """:const:`telegram.constants.STICKER_CHIN`"""
+
+    def __init__(self, point: str, x_shift: float, y_shift: float, scale: float, **_kwargs: Any):
         self.point = point
         self.x_shift = x_shift
         self.y_shift = y_shift
