@@ -18,9 +18,10 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram KeyboardButton."""
 
-from telegram import TelegramObject
 from typing import Any
 
+from telegram import TelegramObject
+
 
 class KeyboardButton(TelegramObject):
     """
@@ -60,12 +61,14 @@ class KeyboardButton(TelegramObject):
 
     """
 
-    def __init__(self,
-                 text: str,
-                 request_contact: bool = None,
-                 request_location: bool = None,
-                 request_poll: bool = None,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        text: str,
+        request_contact: bool = None,
+        request_location: bool = None,
+        request_poll: bool = None,
+        **_kwargs: Any,
+    ):
         # Required
         self.text = text
         # Optionals
@@ -73,5 +76,9 @@ class KeyboardButton(TelegramObject):
         self.request_location = request_location
         self.request_poll = request_poll
 
-        self._id_attrs = (self.text, self.request_contact, self.request_location,
-                          self.request_poll)
+        self._id_attrs = (
+            self.text,
+            self.request_contact,
+            self.request_location,
+            self.request_poll,
+        )
