@@ -16,8 +16,14 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
+# pylint: disable=C0114
+from typing import TYPE_CHECKING, Any
+
 from telegram import TelegramObject
 
+if TYPE_CHECKING:
+    from telegram import Bot
+
 
 class PersonalDetails(TelegramObject):
     """
@@ -32,16 +38,29 @@ class PersonalDetails(TelegramObject):
         country_code (:obj:`str`): Citizenship (ISO 3166-1 alpha-2 country code).
         residence_country_code (:obj:`str`): Country of residence (ISO 3166-1 alpha-2 country
             code).
-        first_name (:obj:`str`): First Name in the language of the user's country of residence.
-        middle_name (:obj:`str`): Optional. Middle Name in the language of the user's country of
+        first_name_native (:obj:`str`): First Name in the language of the user's country of
+            residence.
+        middle_name_native (:obj:`str`): Optional. Middle Name in the language of the user's
+            country of residence.
+        last_name_native (:obj:`str`): Last Name in the language of the user's country of
             residence.
-        last_name (:obj:`str`): Last Name in the language of the user's country of residence.
     """
 
-    def __init__(self, first_name, last_name, birth_date, gender, country_code,
-                 residence_country_code, first_name_native=None,
-                 last_name_native=None, middle_name=None,
-                 middle_name_native=None, bot=None, **kwargs):
+    def __init__(
+        self,
+        first_name: str,
+        last_name: str,
+        birth_date: str,
+        gender: str,
+        country_code: str,
+        residence_country_code: str,
+        first_name_native: str = None,
+        last_name_native: str = None,
+        middle_name: str = None,
+        middle_name_native: str = None,
+        bot: 'Bot' = None,
+        **_kwargs: Any,
+    ):
         # Required
         self.first_name = first_name
         self.last_name = last_name
@@ -56,13 +75,6 @@ class PersonalDetails(TelegramObject):
 
         self.bot = bot
 
-    @classmethod
-    def de_json(cls, data, bot):
-        if not data:
-            return None
-
-        return cls(bot=bot, **data)
-
 
 class ResidentialAddress(TelegramObject):
     """
@@ -77,8 +89,17 @@ class ResidentialAddress(TelegramObject):
         post_code (:obj:`str`): Address post code.
     """
 
-    def __init__(self, street_line1, street_line2, city, state, country_code,
-                 post_code, bot=None, **kwargs):
+    def __init__(
+        self,
+        street_line1: str,
+        street_line2: str,
+        city: str,
+        state: str,
+        country_code: str,
+        post_code: str,
+        bot: 'Bot' = None,
+        **_kwargs: Any,
+    ):
         # Required
         self.street_line1 = street_line1
         self.street_line2 = street_line2
@@ -89,13 +110,6 @@ class ResidentialAddress(TelegramObject):
 
         self.bot = bot
 
-    @classmethod
-    def de_json(cls, data, bot):
-        if not data:
-            return None
-
-        return cls(bot=bot, **data)
-
 
 class IdDocumentData(TelegramObject):
     """
@@ -106,15 +120,8 @@ class IdDocumentData(TelegramObject):
         expiry_date (:obj:`str`): Optional. Date of expiry, in DD.MM.YYYY format.
     """
 
-    def __init__(self, document_no, expiry_date, bot=None, **kwargs):
+    def __init__(self, document_no: str, expiry_date: str, bot: 'Bot' = None, **_kwargs: Any):
         self.document_no = document_no
         self.expiry_date = expiry_date
 
         self.bot = bot
-
-    @classmethod
-    def de_json(cls, data, bot):
-        if not data:
-            return None
-
-        return cls(bot=bot, **data)
