@@ -18,9 +18,10 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram ReplyKeyboardMarkup."""
 
-from telegram import ReplyMarkup, KeyboardButton
+from typing import Any, List, Union
+
+from telegram import KeyboardButton, ReplyMarkup
 from telegram.utils.types import JSONDict
-from typing import List, Union, Any
 
 
 class ReplyKeyboardMarkup(ReplyMarkup):
@@ -64,22 +65,24 @@ class ReplyKeyboardMarkup(ReplyMarkup):
 
     """
 
-    def __init__(self,
-                 keyboard: List[List[Union[str, KeyboardButton]]],
-                 resize_keyboard: bool = False,
-                 one_time_keyboard: bool = False,
-                 selective: bool = False,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        keyboard: List[List[Union[str, KeyboardButton]]],
+        resize_keyboard: bool = False,
+        one_time_keyboard: bool = False,
+        selective: bool = False,
+        **_kwargs: Any,
+    ):
         # Required
         self.keyboard = []
         for row in keyboard:
-            r = []
+            button_row = []
             for button in row:
                 if isinstance(button, KeyboardButton):
-                    r.append(button)  # telegram.KeyboardButton
+                    button_row.append(button)  # telegram.KeyboardButton
                 else:
-                    r.append(KeyboardButton(button))  # str
-            self.keyboard.append(r)
+                    button_row.append(KeyboardButton(button))  # str
+            self.keyboard.append(button_row)
 
         # Optionals
         self.resize_keyboard = bool(resize_keyboard)
@@ -91,22 +94,24 @@ class ReplyKeyboardMarkup(ReplyMarkup):
 
         data['keyboard'] = []
         for row in self.keyboard:
-            r: List[Union[JSONDict, str]] = []
+            button_row: List[Union[JSONDict, str]] = []
             for button in row:
                 if isinstance(button, KeyboardButton):
-                    r.append(button.to_dict())  # telegram.KeyboardButton
+                    button_row.append(button.to_dict())  # telegram.KeyboardButton
                 else:
-                    r.append(button)  # str
-            data['keyboard'].append(r)
+                    button_row.append(button)  # str
+            data['keyboard'].append(button_row)
         return data
 
     @classmethod
-    def from_button(cls,
-                    button: Union[KeyboardButton, str],
-                    resize_keyboard: bool = False,
-                    one_time_keyboard: bool = False,
-                    selective: bool = False,
-                    **kwargs: Any) -> 'ReplyKeyboardMarkup':
+    def from_button(
+        cls,
+        button: Union[KeyboardButton, str],
+        resize_keyboard: bool = False,
+        one_time_keyboard: bool = False,
+        selective: bool = False,
+        **kwargs: Any,
+    ) -> 'ReplyKeyboardMarkup':
         """Shortcut for::
 
             ReplyKeyboardMarkup([[button]], **kwargs)
@@ -135,19 +140,23 @@ class ReplyKeyboardMarkup(ReplyMarkup):
                 Defaults to :obj:`False`.
             **kwargs (:obj:`dict`): Arbitrary keyword arguments.
         """
-        return cls([[button]],
-                   resize_keyboard=resize_keyboard,
-                   one_time_keyboard=one_time_keyboard,
-                   selective=selective,
-                   **kwargs)
+        return cls(
+            [[button]],
+            resize_keyboard=resize_keyboard,
+            one_time_keyboard=one_time_keyboard,
+            selective=selective,
+            **kwargs,
+        )
 
     @classmethod
-    def from_row(cls,
-                 button_row: List[Union[str, KeyboardButton]],
-                 resize_keyboard: bool = False,
-                 one_time_keyboard: bool = False,
-                 selective: bool = False,
-                 **kwargs: Any) -> 'ReplyKeyboardMarkup':
+    def from_row(
+        cls,
+        button_row: List[Union[str, KeyboardButton]],
+        resize_keyboard: bool = False,
+        one_time_keyboard: bool = False,
+        selective: bool = False,
+        **kwargs: Any,
+    ) -> 'ReplyKeyboardMarkup':
         """Shortcut for::
 
             ReplyKeyboardMarkup([button_row], **kwargs)
@@ -177,19 +186,23 @@ class ReplyKeyboardMarkup(ReplyMarkup):
             **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
         """
-        return cls([button_row],
-                   resize_keyboard=resize_keyboard,
-                   one_time_keyboard=one_time_keyboard,
-                   selective=selective,
-                   **kwargs)
+        return cls(
+            [button_row],
+            resize_keyboard=resize_keyboard,
+            one_time_keyboard=one_time_keyboard,
+            selective=selective,
+            **kwargs,
+        )
 
     @classmethod
-    def from_column(cls,
-                    button_column: List[Union[str, KeyboardButton]],
-                    resize_keyboard: bool = False,
-                    one_time_keyboard: bool = False,
-                    selective: bool = False,
-                    **kwargs: Any) -> 'ReplyKeyboardMarkup':
+    def from_column(
+        cls,
+        button_column: List[Union[str, KeyboardButton]],
+        resize_keyboard: bool = False,
+        one_time_keyboard: bool = False,
+        selective: bool = False,
+        **kwargs: Any,
+    ) -> 'ReplyKeyboardMarkup':
         """Shortcut for::
 
             ReplyKeyboardMarkup([[button] for button in button_column], **kwargs)
@@ -220,11 +233,13 @@ class ReplyKeyboardMarkup(ReplyMarkup):
 
         """
         button_grid = [[button] for button in button_column]
-        return cls(button_grid,
-                   resize_keyboard=resize_keyboard,
-                   one_time_keyboard=one_time_keyboard,
-                   selective=selective,
-                   **kwargs)
+        return cls(
+            button_grid,
+            resize_keyboard=resize_keyboard,
+            one_time_keyboard=one_time_keyboard,
+            selective=selective,
+            **kwargs,
+        )
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, self.__class__):
@@ -237,10 +252,14 @@ class ReplyKeyboardMarkup(ReplyMarkup):
                     if button != other.keyboard[idx][jdx]:
                         return False
             return True
-        return super(ReplyKeyboardMarkup, self).__eq__(other)  # pylint: disable=no-member
+        return super().__eq__(other)
 
     def __hash__(self) -> int:
-        return hash((
-            tuple(tuple(button for button in row) for row in self.keyboard),
-            self.resize_keyboard, self.one_time_keyboard, self.selective
-        ))
+        return hash(
+            (
+                tuple(tuple(button for button in row) for row in self.keyboard),
+                self.resize_keyboard,
+                self.one_time_keyboard,
+                self.selective,
+            )
+        )
